# -*- coding: iso-8859-15 -*-
#
#  sfvideoportal
#
#  $Id: plugin.py,v 0.1 2011/04/25 12:49:00 dre Exp $
#
#  Coded by dre (c) 2011
#  Coding idea and design by dre
#  Support: www.dreambox-tools.info
#
#  This plugin is licensed under the Creative Commons 
#  Attribution-NonCommercial-ShareAlike 3.0 Unported 
#  License. To view a copy of this license, visit
#  http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative
#  Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
#
#  Alternatively, this plugin may be distributed and executed on hardware which
#  is licensed by Dream Multimedia GmbH.

#  This plugin is NOT free software. It is open source, you are allowed to
#  modify it (if you keep the license), but it may not be commercially 
#  distributed other than under the conditions noted above.
#

from Components.ActionMap import *
from Components.Button import Button
from Components.ConfigList import ConfigListScreen
from Components.Label import Label
from Components.MenuList import MenuList
from Components.MultiContent import MultiContentEntryText #, MultiContentEntryPixmapAlphaTest
from Components.Pixmap import Pixmap
from Components.config import config, ConfigSubsection, ConfigSelection, ConfigYesNo, getConfigListEntry

from Plugins.Plugin import PluginDescriptor

from Screens.Console import Console
from Screens.HelpMenu import HelpableScreen
from Screens.InfoBar import MoviePlayer
from Screens.MessageBox import MessageBox
from Screens.Screen import Screen

from Tools.Directories import fileExists, createDir

from enigma import loadPNG, eListbox, eListboxPythonMultiContent, gFont, RT_HALIGN_LEFT, eServiceReference
from twisted.web.client import getPage

import os, re

# for localized messages
from . import _

dirlist = [ ("not configured","not configured"),("/media/hdd","/media/hdd"), ("/media/cf","/media/cf"), ("/media/usb","/media/usb"), ("/media/net","/media/net") ]
qualitylist = [ (0,_("high quality")),(1,_("medium quality")),(2,_("low quality")) ]

config.plugins.sfvideoportal = ConfigSubsection()
config.plugins.sfvideoportal.dldir = ConfigSelection(choices = dirlist, default = "not configured")
config.plugins.sfvideoportal.showinextensionsmenu = ConfigYesNo(default = False)
config.plugins.sfvideoportal.defaultquality = ConfigSelection(choices = qualitylist, default = 0)

class sfVideoPortal(Screen, HelpableScreen):
	skin = """
		<screen name="sfvideoportal" position="center,center" size="700,330" title="SF Videoportal">
			<widget name="key_red" position="0,0" size="140,40" valign="center" halign="center" zPosition="5" transparent="1" foregroundColor="white" font="Regular;18"/>
			<ePixmap name="red" pixmap="skin_default/buttons/red.png" position="0,0" size="140,40" zPosition="4" transparent="1" alphatest="on"/>
			<widget name="key_green" position="150,0" size="140,40" valign="center" halign="center" zPosition="5" transparent="1" foregroundColor="white" font="Regular;18"/>
			<ePixmap name="green" pixmap="skin_default/buttons/green.png" position="150,0" size="140,40" zPosition="4" transparent="1" alphatest="on"/>
			<widget name="key_yellow" position="300,0" size="140,40" valign="center" halign="center" zPosition="5" transparent="1" foregroundColor="white" font="Regular;18"/>
			<ePixmap name="yellow" pixmap="skin_default/buttons/yellow.png" position="300,0" size="140,40" zPosition="4" transparent="1" alphatest="on"/>
			<widget name="key_blue" position="450,0" size="140,40" valign="center" halign="center" zPosition="5" transparent="1" foregroundColor="white" font="Regular;18"/>
			<ePixmap name="blue" pixmap="skin_default/buttons/blue.png" position="450,0" size="140,40" zPosition="4" transparent="1" alphatest="on"/>
			<widget name="menulist" position="150,50" size="530,270" scrollbarMode="showOnDemand"/>
			<widget name="submenu" position="680,50" size="20,90" scrollbarMode="showNever" />
			<widget name="mainmenu" position="0,50" size="150,270" scrollbarMode="showNever" />
		</screen>"""
		
	def __init__(self, session, args = 0):
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)
		
		self.mainmenu = []
		#shows isn't completed yet
		#self.mainmenu = [_("Most viewed"), _("Best rated"), _("Newest"), _("Last chance"), _("Shows")]
		self.mainmenu = [_("Most viewed"), _("Best rated"), _("Newest"), _("Last chance")]
		self["mainmenu"] = MenuList(self.mainmenu)
		
		self["mainmenu"].onSelectionChanged.append(self.selectedMenuChanged)
		
		self.menulist = []
		self["menulist"] = MenuList([])
		
		self.submenu = []
		self.submenu = ["1", "2", "3"]
		self["submenu"] = MenuList(self.submenu)
		
		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"ok":		(self.getJson, _("Show details for selected video")),
			"cancel":	(self.close, _("Close plugin")),
		}, -1)
		
		self["ColorActions"] = HelpableActionMap(self, "ColorActions",
		{
			"red":		(self.redPressed, _("Show most viewed videos")),
			"green":	(self.greenPressed, _("Show best rated videos")),
			"yellow":	(self.yellowPressed, _("Show newest videos")),
			"blue":		(self.bluePressed, _("Show last chance videos")),
		}, -1)
		
		self["MenuActions"] = HelpableActionMap(self, "MenuActions",
		{
			"menu":		(self.openConfig, _("Open plugin config screen")),
		}, -1)
		
		self["DirectionActions"] = HelpableActionMap(self, "DirectionActions",
		{
			"up":		(self.up, _("Move cursor up")),
			"down":		(self.down, _("Move cursor down")),
			"left":		(self.changeMenu, _("Change between menu and videos")),
			"right":	(self.changeMenu, _("Change between menu and videos")),
		}, -1)

		self["EPGSelectActions"] = HelpableActionMap(self, "EPGSelectActions",
		{
			"nextBouquet":		(self.getPreviousPage, _("Get previous page")),
			"prevBouquet":		(self.getNextPage, _("Get next page")),
		}, -1)
		
		self["key_red"] = Button(_("Most viewed"))
		self["red"] = Pixmap()
		self["key_green"] = Button(_("Best rated"))
		self["green"] = Pixmap()
		self["key_yellow"] = Button(_("Newest"))
		self["yellow"] = Pixmap()
		self["key_blue"] = Button(_("Last chance"))
		self["blue"] = Pixmap()
		self.currentMenu = "mostviews"
		self.status = "updating"
		self.getDataString("mostviews")
		self.currentList = "mainmenu"

		self["menulist"].selectionEnabled(1)
		self["mainmenu"].selectionEnabled(0)
		
		self["submenu"].onSelectionChanged.append(self.selectionChanged)
	
	def selectedMenuChanged(self):
		selectedMenuEntry = self["mainmenu"].getSelectedIndex()
		if selectedMenuEntry == 0:
			if self.status == "finished":
				self["submenu"].show()
				self.currentMenu = "mostviews"
				self.status = "updating"
				self.getDataString("mostviews")
		elif selectedMenuEntry == 1:
			if self.status == "finished":
				self["submenu"].show()
				self.currentMenu = "bestrated"
				self.status = "updating"
				self.getDataString("bestrated")
		elif selectedMenuEntry == 2:
			if self.status == "finished":
				self["submenu"].show()
				self.currentMenu = "newest"
				self.status = "updating"
				self.getDataString("newest")
		elif selectedMenuEntry == 3:
			if self.status == "finished":
				self["submenu"].show()
				self.currentMenu = "lastchance"
				self.status = "updating"
				self.getDataString("lastchance")
		elif selectedMenuEntry == 4:
			if self.status == "finished":
				self["submenu"].hide()
				self.currentMenu = "shows"
				self.status = "updating"
				self.getShows("sendungen")
	
	def getPreviousPage(self):
		if self.status == "finished" and self.currentMenu != "shows":
			self["submenu"].up()
		
	def getNextPage(self):
		if self.status == "finished" and self.currentMenu != "shows":
			self["submenu"].down()
	
	def selectionChanged(self):
		if self.status == "finished":
			self.status = "updating"
			selectedEntry = self["submenu"].getSelectedIndex()
			self.getDataString(self.currentMenu, str(selectedEntry+1))
		
	def changeMenu(self):
		if self.currentList == "menulist":
			self["menulist"].selectionEnabled(0)
			self["mainmenu"].selectionEnabled(1)
			self.currentList = "mainmenu"
		else:
			self["mainmenu"].selectionEnabled(0)
			self["menulist"].selectionEnabled(1)
			self.currentList = "menulist"
		
	def up(self):
		self[self.currentList].up()
	
	def down(self):
		self[self.currentList].down()
	
	#evtl. fr shortcuts via config!
	def redPressed(self):
		if self.status == "finished":
			self.currentMenu = "mostviews"
			self.status = "updating"
			self["mainmenu"].moveToIndex(0)
			self.getDataString("mostviews")

	def greenPressed(self):
		if self.status == "finished":
			self.currentMenu = "bestrated"
			self.status = "updating"
			self["mainmenu"].moveToIndex(1)
			self.getDataString("bestrated")

	def yellowPressed(self):
		if self.status == "finished":
			self.currentMenu = "newest"
			self.status = "updating"
			self["mainmenu"].moveToIndex(2)
			self.getDataString("newest")

	def bluePressed(self):
		if self.status == "finished":
			self.currentMenu = "lastchance"
			self.status = "updating"
			self["mainmenu"].moveToIndex(3)
			self.getDataString("lastchance")

	def openConfig(self):
		self.session.open(sfVideoPortalConfigScreen)

	def getMenu(self, datafile=""):
		self.datafile = datafile
		
		url = re.findall("{.id.:.(.*?).,", self.datafile)
		videoname = re.findall(".title.:.(.*?).,", self.datafile)
		
		for i in range(len(url)):
			s_videoname = self.replaceSpecialChars(videoname[i])
			self.menulist.append((s_videoname, url[i]))

		self["menulist"].setList(self.menulist)
		self.status = "finished"

	def getDataString(self, target, page="1"):
		self.target = target
		self.menulist = []
		url = "http://videoportal.sf.tv/pushvideosajax/" + target + "?page=" + page
		getPage(url).addCallback(self.getMenu)	
		
	def getShowsMenu(self, showfile=""):
		self.showfile = showfile
		
		idshowname = re.findall("<a class=\"sendung_name\" href=\"/sendung\?id=(.*?)\">(.*?)</a><p class=\"az_description\">", self.showfile)
		
		for j in range(len(idshowname)):
			s_showname = self.replaceSpecialChars(idshowname[j][1])
			self.menulist.append((s_showname, idshowname[j][0]))
			
		self["menulist"].setList(self.menulist)
		self.status = "finished"
		
	def getShows(self, target):
		self.target = target
		self.menulist = []
		url = "http://videoportal.sf.tv/" + target
		getPage(url).addCallback(self.getShowsMenu)
		
	def getJson(self):
		selectedEntry = self["menulist"].getSelectedIndex()
		id = self.menulist[selectedEntry][1]
		
		if self.currentMenu != "shows":
			url = "http://www.videoportal.sf.tv/cvis/segment/%s" %(id)
			getPage(url).addCallback(self.showVideoDetails)
		elif self.currentMenu == "shows":
			url = "http://www.videoportal.sf.tv/sendung?id=%s" %(id)
			getPage(url).addCallback(self.getAvailableShows)
		
	def getAvailableShows(self, availableShows=""):
		self.availableShows = availableShows
		
		self.dataContainer = []
		
		idcurrentShow = re.findall("<h2><a href=\"/video\?id=(.*?);DCSext.zugang=videoportal_sendungsuebersicht\">(.*?)</a></h2>", self.availableShows)
		s_idcurrentShow = self.replaceSpecialChars(idcurrentShow[0][1])
		idlastShows = re.findall("<a class=\"sendung_title\" href=\"/video\?id=(.*?);DCSext.zugang=videoportal_sendungsuebersicht\"><img class=\"icon\" src=\"/i/tv_icon.gif\" width=\"11\" height=\"13\" alt=\"\" /><strong>(.*?)</strong></a>", self.availableShows)
		#idpartofShow = re.findall("<li><a href=\"/video\?id=(.*?);DCSext.zugang=videoportal_sendungsuebersicht\">(.*?)</a></li>", self.availableShows)
		#parts: evtl. durchloopen, bis id = id naechste show
		
		self.dataContainer.append((s_idcurrentShow, idcurrentShow[0][0]))
		
		for k in range(len(idlastShows)):
			s_idlastShows = self.replaceSpecialChars(idlastShows[k][1])
			self.dataContainer.append((s_idlastShows, idlastShows[k][0]))
			
		self.session.open(ShowDetailScreen, self.dataContainer)
		
	
	def showVideoDetails(self, infofile=""):
		self.data = infofile
		
		self.dataContainer = []

		#initial values for variables
		publishdate = "no publish date available"
		description = "no description available"
		title = "no title available"
		self.lqurl = "no low quality stream available"
		self.mqurl = "no medium quality stream available"
		self.hqurl = "no high quality stream available"
		
		#Bemerkungen: Der erste Eintrag in der Datei ist immer das gesuchte Video
		
		#title
		retitle = re.findall(".description_title.:.(.*?)\",", self.data)
		title = self.replaceSpecialChars(retitle[0])

		#description
		redescription = re.findall(".description_lead.:.(.*?).,.[mt]", self.data)
		if redescription[0] != "":
			description = self.replaceSpecialChars(redescription[0])

		#publish kommt nur zwei Mal vor (fuer den gesuchten Beitrag und fuer das gesamte Video
		publish = re.findall(".time_published.:.(.*?).,", self.data)
		for j in range(len(publish)):
				redatetime = publish[j].split()
				redatesplit = redatetime[0].split("-")
				publish[j] = "%s.%s.%s, %s" %(redatesplit[2], redatesplit[1], redatesplit[0], redatetime[1])
				
		#mark_in kommt einmal weniger vor als descritpion_lead (description_lead[1] hat kein mark_in)
		markin = re.findall(".mark_in.:(.*?),", self.data)
		
		#mark_out kommt einmal weniger vor als description_lead (description_lead[1] hat kein mark_out)
		markout = re.findall(".mark_out.:(.*?),", self.data)
		
		#urls
		reurl = re.findall("\"url.:.(.*?).\}", self.data)
		
		for i in range(len(reurl)):
			if reurl[i].endswith("hq1.mp4"):
				self.hqurl = self.replaceBackSlash(reurl[i])
			elif reurl[i].endswith("lq1.mp4"):
				self.lqurl = self.replaceBackSlash(reurl[i])
			elif reurl[i].endswith("mq1.mp4"):
				self.mqurl = self.replaceBackSlash(reurl[i])
			
		#handover to dataContainer
		self.dataContainer.append(title)
		self.dataContainer.append(description)
		self.dataContainer.append(publish[0])
		self.dataContainer.append(float(markin[0]))
		self.dataContainer.append(float(markout[0]))
		self.dataContainer.append(self.hqurl)
		self.dataContainer.append(self.mqurl)
		self.dataContainer.append(self.lqurl)
		
		self.session.open(VideoDetailScreen, self.dataContainer)

	def replaceBackSlash(self, text2replace):
		text2replace = text2replace.replace('\/', '/')
		return text2replace
		
	def replaceSpecialChars(self, text2replace):
		text2replace = text2replace.replace('\u00a0', '\xc2\xa0') #no break space
		text2replace = text2replace.replace('\u00ab', '\xc2\xab') #
		text2replace = text2replace.replace('\u00bb', '\xc2\xbb') #
		text2replace = text2replace.replace('&amp;', '\x26') #&
		text2replace = text2replace.replace('\u2013', '\x2d') #
		text2replace = text2replace.replace('\u00e0', '\xc3\xa0') #
		text2replace = text2replace.replace('\u00e1', '\xc3\xa1') #
		text2replace = text2replace.replace('\u00e2', '\xc3\xa2') #
		text2replace = text2replace.replace('\u00e3', '\xc3\xa3') #
		text2replace = text2replace.replace('\u00e4', '\xc3\xa4') #
		text2replace = text2replace.replace('\u00e5', '\xc3\xa5') #
		text2replace = text2replace.replace('\u00e6', '\xc3\xa6') #
		text2replace = text2replace.replace('\u00e7', '\xc3\xa7') #
		text2replace = text2replace.replace('\u00e8', '\xc3\xa8') #
		text2replace = text2replace.replace('\u00e9', '\xc3\xa9') #
		text2replace = text2replace.replace('\u00ea', '\xc3\xaa') #
		text2replace = text2replace.replace('\u00eb', '\xc3\xab') #
		text2replace = text2replace.replace('\u00ec', '\xc3\xac') #
		text2replace = text2replace.replace('\u00ed', '\xc3\xad') #
		text2replace = text2replace.replace('\u00ee', '\xc3\xae') #
		text2replace = text2replace.replace('\u00f1', '\xc3\xb1') #
		text2replace = text2replace.replace('\u00f2', '\xc3\xb2') #
		text2replace = text2replace.replace('\u00f3', '\xc3\xb3') #
		text2replace = text2replace.replace('\u00f4', '\xc3\xb4') #
		text2replace = text2replace.replace('\u00f5', '\xc3\xb5') #
		text2replace = text2replace.replace('\u00f6', '\xc3\xb6') #
		text2replace = text2replace.replace('\u00f8', '\xc3\xb8') #
		text2replace = text2replace.replace('\u00f9', '\xc3\xb9') #
		text2replace = text2replace.replace('\u00fa', '\xc3\xba') #
		text2replace = text2replace.replace('\u00fb', '\xc3\xbb') #
		text2replace = text2replace.replace('\u00fc', '\xc3\xbc') #
		text2replace = text2replace.replace('\u00c4', '\xc3\x84') #
		text2replace = text2replace.replace('\u00c5', '\xc3\x85') #
		text2replace = text2replace.replace('\u00c6', '\xc3\x86') #
		text2replace = text2replace.replace('\u00d6', '\xc3\x96') #
		text2replace = text2replace.replace('\u00dc', '\xc3\x9c') #
		
		return text2replace

class ShowDetailScreen(Screen, HelpableScreen):
	skin = """
		<screen name="ShowDetailScreen" position="center,center" size="650,520" title="SF Videoportal - Shows">
			<widget name="description" position="0,0" size="650,360" scrollbarMode="showOnDemand"/>
			<widget name="videoinfo" foregroundColor="#f0f0f0" font="Regular;18" position="0,400" size="650,30" transparent="1"/>
			<widget name="menulist" position="0,430" size="610,90" scrollbarMode="showOnDemand"/>
		</screen>"""
		
	def __init__(self, session, dataContainer):
		self.skin = ShowDetailScreen.skin
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)
		
		self.dataContainer = dataContainer
		
		self["videoinfo"] = Label()
		self["videoinfo"].setText(_("Select video quality:"))
		
		self["menulist"] = MenuList([])

		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"cancel":	(self.close, _("Close screen")),
		}, -1)
		
		self.menulist = []
		
		for i in range(len(self.dataContainer)):
			self.menulist.append((self.dataContainer[i][0], self.dataContainer[i][1]))
			
		self["description"] = MenuList(self.menulist)
		
class VideoDetailScreen(Screen, HelpableScreen):
	skin = """
		<screen name="VideoDetailScreen" position="center,center" size="650,520" title="SF Videoportal - Video details">
			<widget name="description" position="0,0" size="650,360" valign="top" halign="left" zPosition="5" transparent="1" foregroundColor="white" font="Regular;18"/>
			<widget name="publishinfo" position="0,360" size="650,40" valign="top" halign="left" zPosition="5" transparent="1" foregroundColor="white" font="Regular;16"/>
			<widget name="videoinfo" foregroundColor="#f0f0f0" font="Regular;18" position="0,400" size="650,30" transparent="1"/>
			<widget name="menulist" position="0,430" size="610,90" scrollbarMode="showOnDemand"/>
		</screen>"""
	
	def __init__(self, session, dataContainer):
		self.skin = VideoDetailScreen.skin
		Screen.__init__(self,session)
		HelpableScreen.__init__(self)
		
		self.dataContainer = dataContainer
		
		self["publishinfo"] = Label()
		self["publishinfo"].setText(_("Published: %s") %(self.dataContainer[2]))
		
		self["description"] = Label()
		self["description"].setText("%s" %(self.dataContainer[1]))
		
		self["videoinfo"] = Label()
		self["videoinfo"].setText(_("Select video quality:"))
		
		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"ok":		(self.downloadVideo, _("Download video in selected quality")),
			"cancel":	(self.close, _("Close screen")),
		}, -1)
		
		self.menulist = []
		
		self.novideo = 0
		
		if self.dataContainer[5] != "no high quality stream available":
			self.menulist.append((_("High quality"), self.dataContainer[5]))
		else:
			self.novideo = 1
		if self.dataContainer[6] != "no medium quality stream available":
			self.menulist.append((_("Medium quality"), self.dataContainer[6]))
		else:
			self.novideo = 1
		if self.dataContainer[7] != "no low quality stream available":
			self.menulist.append((_("Low quality"), self.dataContainer[7]))
		else:
			self.novideo = 1
		
		if self.novideo == 1:
			self["videoinfo"].setText(_("No video available"))
		
		self["menulist"] = MenuList(self.menulist)
		
		self.onShown.append(self.setWindowTitle)
		
		self.onLayoutFinish.append(self.layoutFinished)

	def layoutFinished(self):
		self["menulist"].moveToIndex(config.plugins.sfvideoportal.defaultquality.value)
		
	def setWindowTitle(self):
		self.setTitle(_("%s" %(self.dataContainer[0])))

	def downloadVideo(self):
		streamURL = self["menulist"].getCurrent()[1]
		#-A --> mark_in; -B --> mark_out
		self.session.openWithCallback(self.playVideo, Console, title="Downloading video...", cmdlist = ["/usr/bin/rtmpdump -r %s -A %f -B %f -o %s/sfvideoportal/video.flv --swfVfy=\"http://www.videoportal.sf.tv/flash/videoplayer.swf\"" %(str(streamURL), float(self.dataContainer[3]), float(self.dataContainer[4]), config.plugins.sfvideoportal.dldir.value)])
		
	def playVideo(self):
		myfile = "%s/sfvideoportal/video.flv" %(config.plugins.sfvideoportal.dldir.value)
		myreference = eServiceReference("4097:0:0:0:0:0:0:0:0:0:" + myfile)
		self.session.open(MoviePlayer, myreference)
		
class sfVideoPortalConfigScreen(Screen, ConfigListScreen, HelpableScreen):
	skin = """
		<screen position="center,center" size ="500,180" title="SF Videoportal - Config" >
			<widget name="config" position="0,0" size="500,80" scrollbarMode="showOnDemand" />
			<widget name="InfoText" position="0,80" size="500,60" valign="center" halign="left" zPosition="10" font="Regular;18" transparent="1" />
			<widget name="ButtonGreenDescr" position="30,140" size="220,40" valign="center" halign="left" zPosition="10" font="Regular;18" transparent="1" />
			<widget name="ButtonGreen" pixmap="skin_default/buttons/button_green.png" position="5,152" zPosition="10" size="16,16" transparent="1" alphatest="on" />
		</screen>"""
	
	def __init__(self, session, args = 0):
		self.session = session
		Screen.__init__(self, session)
		HelpableScreen.__init__(self)
		
		self.list = []
		
		self["OkCancelActions"] = HelpableActionMap(self, "OkCancelActions",
		{
			"cancel":	(self.closeScreen, _("Close")),
		}, -1)

		self["ColorActions"] = HelpableActionMap(self, "ColorActions",
		{
			"green":	(self.saveConfig, _("Save settings")),
		}, -1)
		
		self["ButtonGreenDescr"] = Label(_("Save settings"))
		self["ButtonGreen"] = Pixmap()
		self["InfoText"] = Label(_("A folder sfvideoportal will be created below the selected directory upon saving settings"))
		
		ConfigListScreen.__init__(self, self.list)
		
		self.setupScreen()

	def setupScreen(self):
		self.list = []
		self.list.append(getConfigListEntry(_("Target for download of video"), config.plugins.sfvideoportal.dldir))
		self.list.append(getConfigListEntry(_("Default video quality"), config.plugins.sfvideoportal.defaultquality))
		self.list.append(getConfigListEntry(_("Show plugin in extensions menu"), config.plugins.sfvideoportal.showinextensionsmenu))
		
		self["config"].setList(self.list)
	
	def saveConfig(self):
		path = "%s/sfvideoportal" %(config.plugins.sfvideoportal.dldir.value)
		if not fileExists(path):
			status = createDir(path)
		for x in self.list:
			x[1].save()
		info  = self.session.open(MessageBox, _("Settings have been saved"), MessageBox.TYPE_INFO, timeout=5)
			
	def closeScreen(self):
		self.close(self.session)
		
def main(session, **kwargs):
	if 	config.plugins.sfvideoportal.dldir.value == "not configured":
		session.openWithCallback(main, sfVideoPortalConfigScreen, None)
	else:
		session.open(sfVideoPortal)

def Plugins(**kwargs):
	list = [PluginDescriptor(name="SF Videoportal",
		description="Plugin to access SF Videoportal",where = [PluginDescriptor.WHERE_PLUGINMENU], icon="plugin.png",fnc=main)]
	if config.plugins.sfvideoportal.showinextensionsmenu.value:
		list.append(PluginDescriptor(name="SF Videoportal", description="Plugin to access SF Videoportal", where = [PluginDescriptor.WHERE_EXTENSIONSMENU], fnc=main))
	return list
